[CalendarServer-changes] [8255] CalendarServer/trunk

source_changes at macosforge.org source_changes at macosforge.org
Wed Nov 2 12:05:31 PDT 2011


Revision: 8255
          http://trac.macosforge.org/projects/calendarserver/changeset/8255
Author:   sagen at apple.com
Date:     2011-11-02 12:05:30 -0700 (Wed, 02 Nov 2011)
Log Message:
-----------
Make AugmentService on by default, and undo the migration extra change to add AugmentService to the plist.

Modified Paths:
--------------
    CalendarServer/trunk/calendarserver/tap/test/test_util.py
    CalendarServer/trunk/conf/caldavd-apple.plist
    CalendarServer/trunk/contrib/migration/calendarmigrator.py
    CalendarServer/trunk/contrib/migration/test/test_migrator.py
    CalendarServer/trunk/twistedcaldav/stdconfig.py

Modified: CalendarServer/trunk/calendarserver/tap/test/test_util.py
===================================================================
--- CalendarServer/trunk/conf/caldavd-apple.plist	2011-11-02 16:44:49 UTC (rev 8254)
+++ CalendarServer/trunk/conf/caldavd-apple.plist	2011-11-02 19:05:30 UTC (rev 8255)
@@ -191,21 +191,6 @@
       </dict>
     </dict>
 
-    <!-- XML File Augment Service -->
-    <key>AugmentService</key>
-    <dict>
-      <key>type</key>
-      <string>twistedcaldav.directory.augment.AugmentXMLDB</string>
-
-      <key>params</key>
-      <dict>
-        <key>xmlFiles</key>
-        <array>
-          <string>augments.xml</string>
-        </array>
-      </dict>
-    </dict>
-
     <!--
         Special principals
 

Modified: CalendarServer/trunk/contrib/migration/calendarmigrator.py
===================================================================
--- CalendarServer/trunk/contrib/migration/calendarmigrator.py	2011-11-02 16:44:49 UTC (rev 8254)
+++ CalendarServer/trunk/contrib/migration/calendarmigrator.py	2011-11-02 19:05:30 UTC (rev 8255)
@@ -533,15 +533,7 @@
     # If SSL is enabled, redirect HTTP to HTTPS.
     combined["RedirectHTTPToHTTPS"] = enableSSL
 
-    # Add AugmentService which is now not on by default in stdconfig.py
-    combined["AugmentService"] = {
-        "params" : {
-            "xmlFiles" : ["augments.xml"],
-        },
-        "type" : "twistedcaldav.directory.augment.AugmentXMLDB",
-    }
 
-
 def isServiceDisabled(source, service):
     """
     Returns whether or not a service is disabled

Modified: CalendarServer/trunk/contrib/migration/test/test_migrator.py
===================================================================
--- CalendarServer/trunk/contrib/migration/test/test_migrator.py	2011-11-02 16:44:49 UTC (rev 8254)
+++ CalendarServer/trunk/contrib/migration/test/test_migrator.py	2011-11-02 19:05:30 UTC (rev 8255)
@@ -95,7 +95,6 @@
             "SSLCertificate": "/etc/certificates/test.cert.pem",
             "SSLPort": 8443,
             "SSLPrivateKey": "/etc/certificates/test.key.pem",
-            "AugmentService" : DEFAULT_AUGMENT_SERVICE,
         }
         newCombined = { }
         mergePlist(oldCalDAV, oldCardDAV, newCombined)
@@ -132,7 +131,6 @@
             "SSLCertificate": "",
             "SSLPort": 8443,
             "SSLPrivateKey": "",
-            "AugmentService" : DEFAULT_AUGMENT_SERVICE,
         }
         newCombined = { }
         mergePlist(oldCalDAV, oldCardDAV, newCombined)
@@ -169,7 +167,6 @@
             "SSLCertificate": "/etc/certificates/test.cert.pem",
             "SSLPort": 8443,
             "SSLPrivateKey": "/etc/certificates/test.key.pem",
-            "AugmentService" : DEFAULT_AUGMENT_SERVICE,
         }
         newCombined = { }
         mergePlist(oldCalDAV, oldCardDAV, newCombined)
@@ -206,7 +203,6 @@
             "SSLCertificate": "/etc/certificates/test.cert.pem",
             "SSLPort": 8443,
             "SSLPrivateKey": "/etc/certificates/test.key.pem",
-            "AugmentService" : DEFAULT_AUGMENT_SERVICE,
         }
         newCombined = { }
         mergePlist(oldCalDAV, oldCardDAV, newCombined)
@@ -243,7 +239,6 @@
             "SSLCertificate": "/etc/certificates/test.cert.pem",
             "SSLPort": 9999,
             "SSLPrivateKey": "/etc/certificates/test.key.pem",
-            "AugmentService" : DEFAULT_AUGMENT_SERVICE,
         }
         newCombined = { }
         mergePlist(oldCalDAV, oldCardDAV, newCombined)
@@ -277,7 +272,6 @@
             "SSLCertificate": "",
             "SSLPort": 8443,
             "SSLPrivateKey": "",
-            "AugmentService" : DEFAULT_AUGMENT_SERVICE,
         }
         newCombined = { }
         mergePlist(oldCalDAV, oldCardDAV, newCombined)
@@ -306,7 +300,6 @@
             "SSLCertificate": "/etc/certificates/test.cert.pem",
             "SSLPort": 8443,
             "SSLPrivateKey": "/etc/certificates/test.key.pem",
-            "AugmentService" : DEFAULT_AUGMENT_SERVICE,
         }
         newCombined = { }
         mergePlist(oldCalDAV, oldCardDAV, newCombined)
@@ -326,7 +319,6 @@
             "SSLCertificate": "",
             "SSLPort": 8443,
             "SSLPrivateKey": "",
-            "AugmentService" : DEFAULT_AUGMENT_SERVICE,
         }
         newCombined = { }
         mergePlist(oldCalDAV, oldCardDAV, newCombined)
@@ -372,7 +364,6 @@
             "SSLCertificate": "",
             "SSLPort": 8443,
             "SSLPrivateKey": "",
-            "AugmentService" : DEFAULT_AUGMENT_SERVICE,
         }
         newCombined = { }
         mergePlist(oldCalDAV, oldCardDAV, newCombined)
@@ -410,7 +401,6 @@
             "SSLCertificate": "",
             "SSLPort": 8443,
             "SSLPrivateKey": "",
-            "AugmentService" : DEFAULT_AUGMENT_SERVICE,
         }
         newCombined = { }
         mergePlist(oldCalDAV, oldCardDAV, newCombined)
@@ -448,7 +438,6 @@
             "SSLCertificate": "",
             "SSLPort": 8443,
             "SSLPrivateKey": "",
-            "AugmentService" : DEFAULT_AUGMENT_SERVICE,
         }
         newCombined = { }
         mergePlist(oldCalDAV, oldCardDAV, newCombined)

Modified: CalendarServer/trunk/twistedcaldav/stdconfig.py
===================================================================
--- CalendarServer/trunk/twistedcaldav/stdconfig.py	2011-11-02 16:44:49 UTC (rev 8254)
+++ CalendarServer/trunk/twistedcaldav/stdconfig.py	2011-11-02 19:05:30 UTC (rev 8255)
@@ -355,8 +355,8 @@
     #    Augments for the directory service records to add calendar specific attributes.
     #
     "AugmentService": {
-        "type": "",
-        "params" : {}
+        "type": "twistedcaldav.directory.augment.AugmentXMLDB",
+        "params" : DEFAULT_AUGMENT_PARAMS["twistedcaldav.directory.augment.AugmentXMLDB"],
     },
 
     #
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.macosforge.org/pipermail/calendarserver-changes/attachments/20111102/beccb1c0/attachment-0001.html>


More information about the calendarserver-changes mailing list
--- CalendarServer/trunk/calendarserver/tap/test/test_util.py	2011-11-02 16:44:49 UTC (rev 8254)
+++ CalendarServer/trunk/calendarserver/tap/test/test_util.py	2011-11-02 19:05:30 UTC (rev 8255)
@@ -17,6 +17,7 @@
 from calendarserver.tap.util import computeProcessCount, directoryFromConfig
 from twistedcaldav.test.util import TestCase
 from twistedcaldav.config import config
+from twistedcaldav.directory.augment import AugmentXMLDB
 
 class ProcessCountTestCase(TestCase):
 
@@ -53,10 +54,11 @@
 
     def test_directoryFromConfig(self):
         """
-        Ensure augments service is off by default
+        Ensure augments service is on by default
         """
         dir = directoryFromConfig(config)
         for service in dir._recordTypes.values():
             # all directory services belonging to the aggregate have
-            # augmentService set to None
-            self.assertEquals(getattr(service, "augmentService", None), None)
+            # augmentService set to AugmentXMLDB
+            if hasattr(service, "augmentService"):
+                self.assertTrue(isinstance(service.augmentService, AugmentXMLDB))

Modified: CalendarServer/trunk/conf/caldavd-apple.plist
===================================================================